@@ -26,14 +26,14 @@ module's documentation for more information.
 
 =cut
 
-use 5.005;
+use 5.006;
 use strict;
-use Params::Util   '_INSTANCE';
-use PPI::Transform ();
+use Params::Util   0.14 '_INSTANCE';
+use PPI::Transform 1.200 ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.04';
+	$VERSION = '1.05';
 	@ISA     = 'PPI::Transform';
 }
 
@@ -65,7 +65,8 @@ sub document {
 		$operator->isa('PPI::Token::Operator')    or return '';
 		$operator->content eq '->'                or return '';
 		return 1;
-		} );
+	} );
+
 
 	# Lets also do some whitespace cleanup
 	$document->index_locations or return undef;
@@ -79,6 +80,37 @@ sub document {
 	}
 	$document->flush_locations;
 
+	# Remove whitespace in qw//
+	$document->find( sub {
+		my $qw = $_[1];
+		$qw->isa('PPI::Token::QuoteLike::Words') or return '';
+		
+		# FIXME this breaks encapsulation. I'd like to
+		# just make a new qw object and replace this one,
+		# but I just can't figure out how from the PPI docs.
+		# --Steffen
+		my $section = $qw->{sections}[0];
+		my $type    = $section->{type};
+		my $d_left  = substr($type, 0, 1);
+		my $d_right = substr($type, 1, 2);
+		
+		my $content = $qw->content();
+		$content =~ s/^\s*qw\s*\Q$d_left\E\s*/qw$d_left/;
+		$content =~ s/\s*\Q$d_right\E\s*$/$d_right/;
+		$content =~ s/\s+/ /g;
+		
+		$qw->set_content($content);
+		
+		$section->{position} = length("qw$d_left");
+		$section->{size} = length($content) - $section->{position} - 1;
+		
+		return '';
+	} );
+
+	die $document->errstr if $document->errstr;
+
+	$document->flush_locations;
+
 	$document;
 }
 
@@ -101,7 +133,7 @@ For general comments, contact the author.
 
 =head1 AUTHOR
 
-Adam Kennedy <adamk@cpan.org>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
@@ -109,7 +141,7 @@ L<PPI>
 
 =head1 COPYRIGHT
 
-Copyright 2005 - 2008 Adam Kennedy.
+Copyright 2005 - 2009 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
